#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# This file is part of Touchpad-Indicator
#
# Copyright (C) 2010-2018 Lorenzo Carbonell<lorenzo.carbonell.cerezo@gmail.com>
# Copyright (C) 2010-2012 Miguel Angel Santamaría Rogado<leibag@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from Xlib import XK
import KEYSYMDEF
_keysyms = [name for name in dir(KEYSYMDEF)]
for keysym in _keysyms:
    XK.__dict__[keysym] = KEYSYMDEF.__dict__[keysym]
del KEYSYMDEF

XK.load_keysym_group('miscellany')
XK.load_keysym_group('latin1')
XK.load_keysym_group('latin2')
XK.load_keysym_group('latin3')
XK.load_keysym_group('latin4')
XK.load_keysym_group('arabic')
XK.load_keysym_group('cyrillic')
XK.load_keysym_group('greek')
XK.load_keysym_group('hebrew')
XK.load_keysym_group('katakana')
XK.load_keysym_group('korean')
XK.load_keysym_group('publishing')
XK.load_keysym_group('thai')
XK.load_keysym_group('xkb')
XK.load_keysym_group('technical')


PRINTABLE = {
    XK.XK_space: '\u0020',
    XK.XK_exclam: '\u0021',
    XK.XK_quotedbl: '\u0022',
    XK.XK_numbersign: '\u0023',
    XK.XK_dollar: '\u0024',
    XK.XK_percent: '\u0025',
    XK.XK_ampersand: '\u0026',
    XK.XK_apostrophe: '\u0027',
    XK.XK_parenleft: '\u0028',
    XK.XK_parenright: '\u0029',
    XK.XK_asterisk: '\u002A',
    XK.XK_plus: '\u002B',
    XK.XK_comma: '\u002C',
    XK.XK_minus: '\u002D',
    XK.XK_period: '\u002E',
    XK.XK_slash: '\u002F',
    XK.XK_0: '\u0030',
    XK.XK_1: '\u0031',
    XK.XK_2: '\u0032',
    XK.XK_3: '\u0033',
    XK.XK_4: '\u0034',
    XK.XK_5: '\u0035',
    XK.XK_6: '\u0036',
    XK.XK_7: '\u0037',
    XK.XK_8: '\u0038',
    XK.XK_9: '\u0039',
    XK.XK_colon: '\u003A',
    XK.XK_semicolon: '\u003B',
    XK.XK_less: '\u003C',
    XK.XK_equal: '\u003D',
    XK.XK_greater: '\u003E',
    XK.XK_question: '\u003F',
    XK.XK_at: '\u0040',
    XK.XK_A: '\u0041',
    XK.XK_B: '\u0042',
    XK.XK_C: '\u0043',
    XK.XK_D: '\u0044',
    XK.XK_E: '\u0045',
    XK.XK_F: '\u0046',
    XK.XK_G: '\u0047',
    XK.XK_H: '\u0048',
    XK.XK_I: '\u0049',
    XK.XK_J: '\u004A',
    XK.XK_K: '\u004B',
    XK.XK_L: '\u004C',
    XK.XK_M: '\u004D',
    XK.XK_N: '\u004E',
    XK.XK_O: '\u004F',
    XK.XK_P: '\u0050',
    XK.XK_Q: '\u0051',
    XK.XK_R: '\u0052',
    XK.XK_S: '\u0053',
    XK.XK_T: '\u0054',
    XK.XK_U: '\u0055',
    XK.XK_V: '\u0056',
    XK.XK_W: '\u0057',
    XK.XK_X: '\u0058',
    XK.XK_Y: '\u0059',
    XK.XK_Z: '\u005A',
    XK.XK_bracketleft: '\u005B',
    XK.XK_backslash: '\u005C',
    XK.XK_bracketright: '\u005D',
    XK.XK_asciicircum: '\u005E',
    XK.XK_underscore: '\u005F',
    XK.XK_grave: '\u0060',
    XK.XK_a: '\u0061',
    XK.XK_b: '\u0062',
    XK.XK_c: '\u0063',
    XK.XK_d: '\u0064',
    XK.XK_e: '\u0065',
    XK.XK_f: '\u0066',
    XK.XK_g: '\u0067',
    XK.XK_h: '\u0068',
    XK.XK_i: '\u0069',
    XK.XK_j: '\u006A',
    XK.XK_k: '\u006B',
    XK.XK_l: '\u006C',
    XK.XK_m: '\u006D',
    XK.XK_n: '\u006E',
    XK.XK_o: '\u006F',
    XK.XK_p: '\u0070',
    XK.XK_q: '\u0071',
    XK.XK_r: '\u0072',
    XK.XK_s: '\u0073',
    XK.XK_t: '\u0074',
    XK.XK_u: '\u0075',
    XK.XK_v: '\u0076',
    XK.XK_w: '\u0077',
    XK.XK_x: '\u0078',
    XK.XK_y: '\u0079',
    XK.XK_z: '\u007A',
    XK.XK_braceleft: '\u007B',
    XK.XK_bar: '\u007C',
    XK.XK_braceright: '\u007D',
    XK.XK_asciitilde: '\u007E',
    XK.XK_nobreakspace: '\u00A0',
    XK.XK_exclamdown: '\u00A1',
    XK.XK_cent: '\u00A2',
    XK.XK_sterling: '\u00A3',
    XK.XK_currency: '\u00A4',
    XK.XK_yen: '\u00A5',
    XK.XK_brokenbar: '\u00A6',
    XK.XK_section: '\u00A7',
    XK.XK_diaeresis: '\u00A8',
    XK.XK_copyright: '\u00A9',
    XK.XK_ordfeminine: '\u00AA',
    XK.XK_guillemotleft: '\u00AB',
    XK.XK_notsign: '\u00AC',
    XK.XK_hyphen: '\u00AD',
    XK.XK_registered: '\u00AE',
    XK.XK_macron: '\u00AF',
    XK.XK_degree: '\u00B0',
    XK.XK_plusminus: '\u00B1',
    XK.XK_twosuperior: '\u00B2',
    XK.XK_threesuperior: '\u00B3',
    XK.XK_acute: '\u00B4',
    XK.XK_mu: '\u00B5',
    XK.XK_paragraph: '\u00B6',
    XK.XK_periodcentered: '\u00B7',
    XK.XK_cedilla: '\u00B8',
    XK.XK_onesuperior: '\u00B9',
    XK.XK_masculine: '\u00BA',
    XK.XK_guillemotright: '\u00BB',
    XK.XK_onequarter: '\u00BC',
    XK.XK_onehalf: '\u00BD',
    XK.XK_threequarters: '\u00BE',
    XK.XK_questiondown: '\u00BF',
    XK.XK_Agrave: '\u00C0',
    XK.XK_Aacute: '\u00C1',
    XK.XK_Acircumflex: '\u00C2',
    XK.XK_Atilde: '\u00C3',
    XK.XK_Adiaeresis: '\u00C4',
    XK.XK_Aring: '\u00C5',
    XK.XK_AE: '\u00C6',
    XK.XK_Ccedilla: '\u00C7',
    XK.XK_Egrave: '\u00C8',
    XK.XK_Eacute: '\u00C9',
    XK.XK_Ecircumflex: '\u00CA',
    XK.XK_Ediaeresis: '\u00CB',
    XK.XK_Igrave: '\u00CC',
    XK.XK_Iacute: '\u00CD',
    XK.XK_Icircumflex: '\u00CE',
    XK.XK_Idiaeresis: '\u00CF',
    XK.XK_ETH: '\u00D0',
    XK.XK_Ntilde: '\u00D1',
    XK.XK_Ograve: '\u00D2',
    XK.XK_Oacute: '\u00D3',
    XK.XK_Ocircumflex: '\u00D4',
    XK.XK_Otilde: '\u00D5',
    XK.XK_Odiaeresis: '\u00D6',
    XK.XK_multiply: '\u00D7',
    XK.XK_Oslash: '\u00D8',
    XK.XK_Ooblique: '\u00D8',
    XK.XK_Ugrave: '\u00D9',
    XK.XK_Uacute: '\u00DA',
    XK.XK_Ucircumflex: '\u00DB',
    XK.XK_Udiaeresis: '\u00DC',
    XK.XK_Yacute: '\u00DD',
    XK.XK_THORN: '\u00DE',
    XK.XK_ssharp: '\u00DF',
    XK.XK_agrave: '\u00E0',
    XK.XK_aacute: '\u00E1',
    XK.XK_acircumflex: '\u00E2',
    XK.XK_atilde: '\u00E3',
    XK.XK_adiaeresis: '\u00E4',
    XK.XK_aring: '\u00E5',
    XK.XK_ae: '\u00E6',
    XK.XK_ccedilla: '\u00E7',
    XK.XK_egrave: '\u00E8',
    XK.XK_eacute: '\u00E9',
    XK.XK_ecircumflex: '\u00EA',
    XK.XK_ediaeresis: '\u00EB',
    XK.XK_igrave: '\u00EC',
    XK.XK_iacute: '\u00ED',
    XK.XK_icircumflex: '\u00EE',
    XK.XK_idiaeresis: '\u00EF',
    XK.XK_eth: '\u00F0',
    XK.XK_ntilde: '\u00F1',
    XK.XK_ograve: '\u00F2',
    XK.XK_oacute: '\u00F3',
    XK.XK_ocircumflex: '\u00F4',
    XK.XK_otilde: '\u00F5',
    XK.XK_odiaeresis: '\u00F6',
    XK.XK_division: '\u00F7',
    XK.XK_oslash: '\u00F8',
    XK.XK_ooblique: '\u00F8',
    XK.XK_ugrave: '\u00F9',
    XK.XK_uacute: '\u00FA',
    XK.XK_ucircumflex: '\u00FB',
    XK.XK_udiaeresis: '\u00FC',
    XK.XK_yacute: '\u00FD',
    XK.XK_thorn: '\u00FE',
    XK.XK_ydiaeresis: '\u00FF',
    XK.XK_Aogonek: '\u0104',
    XK.XK_breve: '\u02D8',
    XK.XK_Lstroke: '\u0141',
    XK.XK_Lcaron: '\u013D',
    XK.XK_Sacute: '\u015A',
    XK.XK_Scaron: '\u0160',
    XK.XK_Scedilla: '\u015E',
    XK.XK_Tcaron: '\u0164',
    XK.XK_Zacute: '\u0179',
    XK.XK_Zcaron: '\u017D',
    XK.XK_Zabovedot: '\u017B',
    XK.XK_aogonek: '\u0105',
    XK.XK_ogonek: '\u02DB',
    XK.XK_lstroke: '\u0142',
    XK.XK_lcaron: '\u013E',
    XK.XK_sacute: '\u015B',
    XK.XK_caron: '\u02C7',
    XK.XK_scaron: '\u0161',
    XK.XK_scedilla: '\u015F',
    XK.XK_tcaron: '\u0165',
    XK.XK_zacute: '\u017A',
    XK.XK_doubleacute: '\u02DD',
    XK.XK_zcaron: '\u017E',
    XK.XK_zabovedot: '\u017C',
    XK.XK_Racute: '\u0154',
    XK.XK_Abreve: '\u0102',
    XK.XK_Lacute: '\u0139',
    XK.XK_Cacute: '\u0106',
    XK.XK_Ccaron: '\u010C',
    XK.XK_Eogonek: '\u0118',
    XK.XK_Ecaron: '\u011A',
    XK.XK_Dcaron: '\u010E',
    XK.XK_Dstroke: '\u0110',
    XK.XK_Nacute: '\u0143',
    XK.XK_Ncaron: '\u0147',
    XK.XK_Odoubleacute: '\u0150',
    XK.XK_Rcaron: '\u0158',
    XK.XK_Uring: '\u016E',
    XK.XK_Udoubleacute: '\u0170',
    XK.XK_Tcedilla: '\u0162',
    XK.XK_racute: '\u0155',
    XK.XK_abreve: '\u0103',
    XK.XK_lacute: '\u013A',
    XK.XK_cacute: '\u0107',
    XK.XK_ccaron: '\u010D',
    XK.XK_eogonek: '\u0119',
    XK.XK_ecaron: '\u011B',
    XK.XK_dcaron: '\u010F',
    XK.XK_dstroke: '\u0111',
    XK.XK_nacute: '\u0144',
    XK.XK_ncaron: '\u0148',
    XK.XK_odoubleacute: '\u0151',
    XK.XK_rcaron: '\u0159',
    XK.XK_uring: '\u016F',
    XK.XK_udoubleacute: '\u0171',
    XK.XK_tcedilla: '\u0163',
    XK.XK_abovedot: '\u02D9',
    XK.XK_Hstroke: '\u0126',
    XK.XK_Hcircumflex: '\u0124',
    XK.XK_Iabovedot: '\u0130',
    XK.XK_Gbreve: '\u011E',
    XK.XK_Jcircumflex: '\u0134',
    XK.XK_hstroke: '\u0127',
    XK.XK_hcircumflex: '\u0125',
    XK.XK_idotless: '\u0131',
    XK.XK_gbreve: '\u011F',
    XK.XK_jcircumflex: '\u0135',
    XK.XK_Cabovedot: '\u010A',
    XK.XK_Ccircumflex: '\u0108',
    XK.XK_Gabovedot: '\u0120',
    XK.XK_Gcircumflex: '\u011C',
    XK.XK_Ubreve: '\u016C',
    XK.XK_Scircumflex: '\u015C',
    XK.XK_cabovedot: '\u010B',
    XK.XK_ccircumflex: '\u0109',
    XK.XK_gabovedot: '\u0121',
    XK.XK_gcircumflex: '\u011D',
    XK.XK_ubreve: '\u016D',
    XK.XK_scircumflex: '\u015D',
    XK.XK_kra: '\u0138',
    XK.XK_Rcedilla: '\u0156',
    XK.XK_Itilde: '\u0128',
    XK.XK_Lcedilla: '\u013B',
    XK.XK_Emacron: '\u0112',
    XK.XK_Gcedilla: '\u0122',
    XK.XK_Tslash: '\u0166',
    XK.XK_rcedilla: '\u0157',
    XK.XK_itilde: '\u0129',
    XK.XK_lcedilla: '\u013C',
    XK.XK_emacron: '\u0113',
    XK.XK_gcedilla: '\u0123',
    XK.XK_tslash: '\u0167',
    XK.XK_ENG: '\u014A',
    XK.XK_eng: '\u014B',
    XK.XK_Amacron: '\u0100',
    XK.XK_Iogonek: '\u012E',
    XK.XK_Eabovedot: '\u0116',
    XK.XK_Imacron: '\u012A',
    XK.XK_Ncedilla: '\u0145',
    XK.XK_Omacron: '\u014C',
    XK.XK_Kcedilla: '\u0136',
    XK.XK_Uogonek: '\u0172',
    XK.XK_Utilde: '\u0168',
    XK.XK_Umacron: '\u016A',
    XK.XK_amacron: '\u0101',
    XK.XK_iogonek: '\u012F',
    XK.XK_eabovedot: '\u0117',
    XK.XK_imacron: '\u012B',
    XK.XK_ncedilla: '\u0146',
    XK.XK_omacron: '\u014D',
    XK.XK_kcedilla: '\u0137',
    XK.XK_uogonek: '\u0173',
    XK.XK_utilde: '\u0169',
    XK.XK_umacron: '\u016B',
    XK.XK_Wcircumflex: '\u0174',
    XK.XK_wcircumflex: '\u0175',
    XK.XK_Ycircumflex: '\u0176',
    XK.XK_ycircumflex: '\u0177',
    XK.XK_Babovedot: '\u1E02',
    XK.XK_babovedot: '\u1E03',
    XK.XK_Dabovedot: '\u1E0A',
    XK.XK_dabovedot: '\u1E0B',
    XK.XK_Fabovedot: '\u1E1E',
    XK.XK_fabovedot: '\u1E1F',
    XK.XK_Mabovedot: '\u1E40',
    XK.XK_mabovedot: '\u1E41',
    XK.XK_Pabovedot: '\u1E56',
    XK.XK_pabovedot: '\u1E57',
    XK.XK_Sabovedot: '\u1E60',
    XK.XK_sabovedot: '\u1E61',
    XK.XK_Tabovedot: '\u1E6A',
    XK.XK_tabovedot: '\u1E6B',
    XK.XK_Wgrave: '\u1E80',
    XK.XK_wgrave: '\u1E81',
    XK.XK_Wacute: '\u1E82',
    XK.XK_wacute: '\u1E83',
    XK.XK_Wdiaeresis: '\u1E84',
    XK.XK_wdiaeresis: '\u1E85',
    XK.XK_Ygrave: '\u1EF2',
    XK.XK_ygrave: '\u1EF3',
    XK.XK_OE: '\u0152',
    XK.XK_oe: '\u0153',
    XK.XK_Ydiaeresis: '\u0178',
    XK.XK_overline: '\u203E',
    XK.XK_kana_fullstop: '\u3002',
    XK.XK_kana_openingbracket: '\u300C',
    XK.XK_kana_closingbracket: '\u300D',
    XK.XK_kana_comma: '\u3001',
    XK.XK_kana_conjunctive: '\u30FB',
    XK.XK_kana_WO: '\u30F2',
    XK.XK_kana_a: '\u30A1',
    XK.XK_kana_i: '\u30A3',
    XK.XK_kana_u: '\u30A5',
    XK.XK_kana_e: '\u30A7',
    XK.XK_kana_o: '\u30A9',
    XK.XK_kana_ya: '\u30E3',
    XK.XK_kana_yu: '\u30E5',
    XK.XK_kana_yo: '\u30E7',
    XK.XK_kana_tsu: '\u30C3',
    XK.XK_prolongedsound: '\u30FC',
    XK.XK_kana_A: '\u30A2',
    XK.XK_kana_I: '\u30A4',
    XK.XK_kana_U: '\u30A6',
    XK.XK_kana_E: '\u30A8',
    XK.XK_kana_O: '\u30AA',
    XK.XK_kana_KA: '\u30AB',
    XK.XK_kana_KI: '\u30AD',
    XK.XK_kana_KU: '\u30AF',
    XK.XK_kana_KE: '\u30B1',
    XK.XK_kana_KO: '\u30B3',
    XK.XK_kana_SA: '\u30B5',
    XK.XK_kana_SHI: '\u30B7',
    XK.XK_kana_SU: '\u30B9',
    XK.XK_kana_SE: '\u30BB',
    XK.XK_kana_SO: '\u30BD',
    XK.XK_kana_TA: '\u30BF',
    XK.XK_kana_CHI: '\u30C1',
    XK.XK_kana_TSU: '\u30C4',
    XK.XK_kana_TE: '\u30C6',
    XK.XK_kana_TO: '\u30C8',
    XK.XK_kana_NA: '\u30CA',
    XK.XK_kana_NI: '\u30CB',
    XK.XK_kana_NU: '\u30CC',
    XK.XK_kana_NE: '\u30CD',
    XK.XK_kana_NO: '\u30CE',
    XK.XK_kana_HA: '\u30CF',
    XK.XK_kana_HI: '\u30D2',
    XK.XK_kana_FU: '\u30D5',
    XK.XK_kana_HE: '\u30D8',
    XK.XK_kana_HO: '\u30DB',
    XK.XK_kana_MA: '\u30DE',
    XK.XK_kana_MI: '\u30DF',
    XK.XK_kana_MU: '\u30E0',
    XK.XK_kana_ME: '\u30E1',
    XK.XK_kana_MO: '\u30E2',
    XK.XK_kana_YA: '\u30E4',
    XK.XK_kana_YU: '\u30E6',
    XK.XK_kana_YO: '\u30E8',
    XK.XK_kana_RA: '\u30E9',
    XK.XK_kana_RI: '\u30EA',
    XK.XK_kana_RU: '\u30EB',
    XK.XK_kana_RE: '\u30EC',
    XK.XK_kana_RO: '\u30ED',
    XK.XK_kana_WA: '\u30EF',
    XK.XK_kana_N: '\u30F3',
    XK.XK_voicedsound: '\u309B',
    XK.XK_semivoicedsound: '\u309C',
    XK.XK_Farsi_0: '\u06F0',
    XK.XK_Farsi_1: '\u06F1',
    XK.XK_Farsi_2: '\u06F2',
    XK.XK_Farsi_3: '\u06F3',
    XK.XK_Farsi_4: '\u06F4',
    XK.XK_Farsi_5: '\u06F5',
    XK.XK_Farsi_6: '\u06F6',
    XK.XK_Farsi_7: '\u06F7',
    XK.XK_Farsi_8: '\u06F8',
    XK.XK_Farsi_9: '\u06F9',
    XK.XK_Arabic_percent: '\u066A',
    XK.XK_Arabic_superscript_alef: '\u0670',
    XK.XK_Arabic_tteh: '\u0679',
    XK.XK_Arabic_peh: '\u067E',
    XK.XK_Arabic_tcheh: '\u0686',
    XK.XK_Arabic_ddal: '\u0688',
    XK.XK_Arabic_rreh: '\u0691',
    XK.XK_Arabic_comma: '\u060C',
    XK.XK_Arabic_fullstop: '\u06D4',
    XK.XK_Arabic_0: '\u0660',
    XK.XK_Arabic_1: '\u0661',
    XK.XK_Arabic_2: '\u0662',
    XK.XK_Arabic_3: '\u0663',
    XK.XK_Arabic_4: '\u0664',
    XK.XK_Arabic_5: '\u0665',
    XK.XK_Arabic_6: '\u0666',
    XK.XK_Arabic_7: '\u0667',
    XK.XK_Arabic_8: '\u0668',
    XK.XK_Arabic_9: '\u0669',
    XK.XK_Arabic_semicolon: '\u061B',
    XK.XK_Arabic_question_mark: '\u061F',
    XK.XK_Arabic_hamza: '\u0621',
    XK.XK_Arabic_maddaonalef: '\u0622',
    XK.XK_Arabic_hamzaonalef: '\u0623',
    XK.XK_Arabic_hamzaonwaw: '\u0624',
    XK.XK_Arabic_hamzaunderalef: '\u0625',
    XK.XK_Arabic_hamzaonyeh: '\u0626',
    XK.XK_Arabic_alef: '\u0627',
    XK.XK_Arabic_beh: '\u0628',
    XK.XK_Arabic_tehmarbuta: '\u0629',
    XK.XK_Arabic_teh: '\u062A',
    XK.XK_Arabic_theh: '\u062B',
    XK.XK_Arabic_jeem: '\u062C',
    XK.XK_Arabic_hah: '\u062D',
    XK.XK_Arabic_khah: '\u062E',
    XK.XK_Arabic_dal: '\u062F',
    XK.XK_Arabic_thal: '\u0630',
    XK.XK_Arabic_ra: '\u0631',
    XK.XK_Arabic_zain: '\u0632',
    XK.XK_Arabic_seen: '\u0633',
    XK.XK_Arabic_sheen: '\u0634',
    XK.XK_Arabic_sad: '\u0635',
    XK.XK_Arabic_dad: '\u0636',
    XK.XK_Arabic_tah: '\u0637',
    XK.XK_Arabic_zah: '\u0638',
    XK.XK_Arabic_ain: '\u0639',
    XK.XK_Arabic_ghain: '\u063A',
    XK.XK_Arabic_tatweel: '\u0640',
    XK.XK_Arabic_feh: '\u0641',
    XK.XK_Arabic_qaf: '\u0642',
    XK.XK_Arabic_kaf: '\u0643',
    XK.XK_Arabic_lam: '\u0644',
    XK.XK_Arabic_meem: '\u0645',
    XK.XK_Arabic_noon: '\u0646',
    XK.XK_Arabic_ha: '\u0647',
    XK.XK_Arabic_waw: '\u0648',
    XK.XK_Arabic_alefmaksura: '\u0649',
    XK.XK_Arabic_yeh: '\u064A',
    XK.XK_Arabic_fathatan: '\u064B',
    XK.XK_Arabic_dammatan: '\u064C',
    XK.XK_Arabic_kasratan: '\u064D',
    XK.XK_Arabic_fatha: '\u064E',
    XK.XK_Arabic_damma: '\u064F',
    XK.XK_Arabic_kasra: '\u0650',
    XK.XK_Arabic_shadda: '\u0651',
    XK.XK_Arabic_sukun: '\u0652',
    XK.XK_Arabic_madda_above: '\u0653',
    XK.XK_Arabic_hamza_above: '\u0654',
    XK.XK_Arabic_hamza_below: '\u0655',
    XK.XK_Arabic_jeh: '\u0698',
    XK.XK_Arabic_veh: '\u06A4',
    XK.XK_Arabic_keheh: '\u06A9',
    XK.XK_Arabic_gaf: '\u06AF',
    XK.XK_Arabic_noon_ghunna: '\u06BA',
    XK.XK_Arabic_heh_doachashmee: '\u06BE',
    XK.XK_Farsi_yeh: '\u06CC',
    XK.XK_Arabic_farsi_yeh: '\u06CC',
    XK.XK_Arabic_yeh_baree: '\u06D2',
    XK.XK_Arabic_heh_goal: '\u06C1',
    XK.XK_Cyrillic_GHE_bar: '\u0492',
    XK.XK_Cyrillic_ghe_bar: '\u0493',
    XK.XK_Cyrillic_ZHE_descender: '\u0496',
    XK.XK_Cyrillic_zhe_descender: '\u0497',
    XK.XK_Cyrillic_KA_descender: '\u049A',
    XK.XK_Cyrillic_ka_descender: '\u049B',
    XK.XK_Cyrillic_KA_vertstroke: '\u049C',
    XK.XK_Cyrillic_ka_vertstroke: '\u049D',
    XK.XK_Cyrillic_EN_descender: '\u04A2',
    XK.XK_Cyrillic_en_descender: '\u04A3',
    XK.XK_Cyrillic_U_straight: '\u04AE',
    XK.XK_Cyrillic_u_straight: '\u04AF',
    XK.XK_Cyrillic_U_straight_bar: '\u04B0',
    XK.XK_Cyrillic_u_straight_bar: '\u04B1',
    XK.XK_Cyrillic_HA_descender: '\u04B2',
    XK.XK_Cyrillic_ha_descender: '\u04B3',
    XK.XK_Cyrillic_CHE_descender: '\u04B6',
    XK.XK_Cyrillic_che_descender: '\u04B7',
    XK.XK_Cyrillic_CHE_vertstroke: '\u04B8',
    XK.XK_Cyrillic_che_vertstroke: '\u04B9',
    XK.XK_Cyrillic_SHHA: '\u04BA',
    XK.XK_Cyrillic_shha: '\u04BB',
    XK.XK_Cyrillic_SCHWA: '\u04D8',
    XK.XK_Cyrillic_schwa: '\u04D9',
    XK.XK_Cyrillic_I_macron: '\u04E2',
    XK.XK_Cyrillic_i_macron: '\u04E3',
    XK.XK_Cyrillic_O_bar: '\u04E8',
    XK.XK_Cyrillic_o_bar: '\u04E9',
    XK.XK_Cyrillic_U_macron: '\u04EE',
    XK.XK_Cyrillic_u_macron: '\u04EF',
    XK.XK_Serbian_dje: '\u0452',
    XK.XK_Macedonia_gje: '\u0453',
    XK.XK_Cyrillic_io: '\u0451',
    XK.XK_Ukrainian_ie: '\u0454',
    XK.XK_Macedonia_dse: '\u0455',
    XK.XK_Ukrainian_i: '\u0456',
    XK.XK_Ukrainian_yi: '\u0457',
    XK.XK_Cyrillic_je: '\u0458',
    XK.XK_Cyrillic_lje: '\u0459',
    XK.XK_Cyrillic_nje: '\u045A',
    XK.XK_Serbian_tshe: '\u045B',
    XK.XK_Macedonia_kje: '\u045C',
    XK.XK_Ukrainian_ghe_with_upturn: '\u0491',
    XK.XK_Byelorussian_shortu: '\u045E',
    XK.XK_Cyrillic_dzhe: '\u045F',
    XK.XK_numerosign: '\u2116',
    XK.XK_Serbian_DJE: '\u0402',
    XK.XK_Macedonia_GJE: '\u0403',
    XK.XK_Cyrillic_IO: '\u0401',
    XK.XK_Ukrainian_IE: '\u0404',
    XK.XK_Macedonia_DSE: '\u0405',
    XK.XK_Ukrainian_I: '\u0406',
    XK.XK_Ukrainian_YI: '\u0407',
    XK.XK_Cyrillic_JE: '\u0408',
    XK.XK_Cyrillic_LJE: '\u0409',
    XK.XK_Cyrillic_NJE: '\u040A',
    XK.XK_Serbian_TSHE: '\u040B',
    XK.XK_Macedonia_KJE: '\u040C',
    XK.XK_Ukrainian_GHE_WITH_UPTURN: '\u0490',
    XK.XK_Byelorussian_SHORTU: '\u040E',
    XK.XK_Cyrillic_DZHE: '\u040F',
    XK.XK_Cyrillic_yu: '\u044E',
    XK.XK_Cyrillic_a: '\u0430',
    XK.XK_Cyrillic_be: '\u0431',
    XK.XK_Cyrillic_tse: '\u0446',
    XK.XK_Cyrillic_de: '\u0434',
    XK.XK_Cyrillic_ie: '\u0435',
    XK.XK_Cyrillic_ef: '\u0444',
    XK.XK_Cyrillic_ghe: '\u0433',
    XK.XK_Cyrillic_ha: '\u0445',
    XK.XK_Cyrillic_i: '\u0438',
    XK.XK_Cyrillic_shorti: '\u0439',
    XK.XK_Cyrillic_ka: '\u043A',
    XK.XK_Cyrillic_el: '\u043B',
    XK.XK_Cyrillic_em: '\u043C',
    XK.XK_Cyrillic_en: '\u043D',
    XK.XK_Cyrillic_o: '\u043E',
    XK.XK_Cyrillic_pe: '\u043F',
    XK.XK_Cyrillic_ya: '\u044F',
    XK.XK_Cyrillic_er: '\u0440',
    XK.XK_Cyrillic_es: '\u0441',
    XK.XK_Cyrillic_te: '\u0442',
    XK.XK_Cyrillic_u: '\u0443',
    XK.XK_Cyrillic_zhe: '\u0436',
    XK.XK_Cyrillic_ve: '\u0432',
    XK.XK_Cyrillic_softsign: '\u044C',
    XK.XK_Cyrillic_yeru: '\u044B',
    XK.XK_Cyrillic_ze: '\u0437',
    XK.XK_Cyrillic_sha: '\u0448',
    XK.XK_Cyrillic_e: '\u044D',
    XK.XK_Cyrillic_shcha: '\u0449',
    XK.XK_Cyrillic_che: '\u0447',
    XK.XK_Cyrillic_hardsign: '\u044A',
    XK.XK_Cyrillic_YU: '\u042E',
    XK.XK_Cyrillic_A: '\u0410',
    XK.XK_Cyrillic_BE: '\u0411',
    XK.XK_Cyrillic_TSE: '\u0426',
    XK.XK_Cyrillic_DE: '\u0414',
    XK.XK_Cyrillic_IE: '\u0415',
    XK.XK_Cyrillic_EF: '\u0424',
    XK.XK_Cyrillic_GHE: '\u0413',
    XK.XK_Cyrillic_HA: '\u0425',
    XK.XK_Cyrillic_I: '\u0418',
    XK.XK_Cyrillic_SHORTI: '\u0419',
    XK.XK_Cyrillic_KA: '\u041A',
    XK.XK_Cyrillic_EL: '\u041B',
    XK.XK_Cyrillic_EM: '\u041C',
    XK.XK_Cyrillic_EN: '\u041D',
    XK.XK_Cyrillic_O: '\u041E',
    XK.XK_Cyrillic_PE: '\u041F',
    XK.XK_Cyrillic_YA: '\u042F',
    XK.XK_Cyrillic_ER: '\u0420',
    XK.XK_Cyrillic_ES: '\u0421',
    XK.XK_Cyrillic_TE: '\u0422',
    XK.XK_Cyrillic_U: '\u0423',
    XK.XK_Cyrillic_ZHE: '\u0416',
    XK.XK_Cyrillic_VE: '\u0412',
    XK.XK_Cyrillic_SOFTSIGN: '\u042C',
    XK.XK_Cyrillic_YERU: '\u042B',
    XK.XK_Cyrillic_ZE: '\u0417',
    XK.XK_Cyrillic_SHA: '\u0428',
    XK.XK_Cyrillic_E: '\u042D',
    XK.XK_Cyrillic_SHCHA: '\u0429',
    XK.XK_Cyrillic_CHE: '\u0427',
    XK.XK_Cyrillic_HARDSIGN: '\u042A',
    XK.XK_Greek_ALPHAaccent: '\u0386',
    XK.XK_Greek_EPSILONaccent: '\u0388',
    XK.XK_Greek_ETAaccent: '\u0389',
    XK.XK_Greek_IOTAaccent: '\u038A',
    XK.XK_Greek_IOTAdieresis: '\u03AA',
    XK.XK_Greek_OMICRONaccent: '\u038C',
    XK.XK_Greek_UPSILONaccent: '\u038E',
    XK.XK_Greek_UPSILONdieresis: '\u03AB',
    XK.XK_Greek_OMEGAaccent: '\u038F',
    XK.XK_Greek_accentdieresis: '\u0385',
    XK.XK_Greek_horizbar: '\u2015',
    XK.XK_Greek_alphaaccent: '\u03AC',
    XK.XK_Greek_epsilonaccent: '\u03AD',
    XK.XK_Greek_etaaccent: '\u03AE',
    XK.XK_Greek_iotaaccent: '\u03AF',
    XK.XK_Greek_iotadieresis: '\u03CA',
    XK.XK_Greek_iotaaccentdieresis: '\u0390',
    XK.XK_Greek_omicronaccent: '\u03CC',
    XK.XK_Greek_upsilonaccent: '\u03CD',
    XK.XK_Greek_upsilondieresis: '\u03CB',
    XK.XK_Greek_upsilonaccentdieresis: '\u03B0',
    XK.XK_Greek_omegaaccent: '\u03CE',
    XK.XK_Greek_ALPHA: '\u0391',
    XK.XK_Greek_BETA: '\u0392',
    XK.XK_Greek_GAMMA: '\u0393',
    XK.XK_Greek_DELTA: '\u0394',
    XK.XK_Greek_EPSILON: '\u0395',
    XK.XK_Greek_ZETA: '\u0396',
    XK.XK_Greek_ETA: '\u0397',
    XK.XK_Greek_THETA: '\u0398',
    XK.XK_Greek_IOTA: '\u0399',
    XK.XK_Greek_KAPPA: '\u039A',
    XK.XK_Greek_LAMDA: '\u039B',
    XK.XK_Greek_LAMBDA: '\u039B',
    XK.XK_Greek_MU: '\u039C',
    XK.XK_Greek_NU: '\u039D',
    XK.XK_Greek_XI: '\u039E',
    XK.XK_Greek_OMICRON: '\u039F',
    XK.XK_Greek_PI: '\u03A0',
    XK.XK_Greek_RHO: '\u03A1',
    XK.XK_Greek_SIGMA: '\u03A3',
    XK.XK_Greek_TAU: '\u03A4',
    XK.XK_Greek_UPSILON: '\u03A5',
    XK.XK_Greek_PHI: '\u03A6',
    XK.XK_Greek_CHI: '\u03A7',
    XK.XK_Greek_PSI: '\u03A8',
    XK.XK_Greek_OMEGA: '\u03A9',
    XK.XK_Greek_alpha: '\u03B1',
    XK.XK_Greek_beta: '\u03B2',
    XK.XK_Greek_gamma: '\u03B3',
    XK.XK_Greek_delta: '\u03B4',
    XK.XK_Greek_epsilon: '\u03B5',
    XK.XK_Greek_zeta: '\u03B6',
    XK.XK_Greek_eta: '\u03B7',
    XK.XK_Greek_theta: '\u03B8',
    XK.XK_Greek_iota: '\u03B9',
    XK.XK_Greek_kappa: '\u03BA',
    XK.XK_Greek_lamda: '\u03BB',
    XK.XK_Greek_lambda: '\u03BB',
    XK.XK_Greek_mu: '\u03BC',
    XK.XK_Greek_nu: '\u03BD',
    XK.XK_Greek_xi: '\u03BE',
    XK.XK_Greek_omicron: '\u03BF',
    XK.XK_Greek_pi: '\u03C0',
    XK.XK_Greek_rho: '\u03C1',
    XK.XK_Greek_sigma: '\u03C3',
    XK.XK_Greek_finalsmallsigma: '\u03C2',
    XK.XK_Greek_tau: '\u03C4',
    XK.XK_Greek_upsilon: '\u03C5',
    XK.XK_Greek_phi: '\u03C6',
    XK.XK_Greek_chi: '\u03C7',
    XK.XK_Greek_psi: '\u03C8',
    XK.XK_Greek_omega: '\u03C9',
    XK.XK_emspace: '\u2003',
    XK.XK_enspace: '\u2002',
    XK.XK_em3space: '\u2004',
    XK.XK_em4space: '\u2005',
    XK.XK_digitspace: '\u2007',
    XK.XK_punctspace: '\u2008',
    XK.XK_thinspace: '\u2009',
    XK.XK_hairspace: '\u200A',
    XK.XK_emdash: '\u2014',
    XK.XK_endash: '\u2013',
    XK.XK_signifblank: '\u2423',
    XK.XK_ellipsis: '\u2026',
    XK.XK_doubbaselinedot: '\u2025',
    XK.XK_onethird: '\u2153',
    XK.XK_twothirds: '\u2154',
    XK.XK_onefifth: '\u2155',
    XK.XK_twofifths: '\u2156',
    XK.XK_threefifths: '\u2157',
    XK.XK_fourfifths: '\u2158',
    XK.XK_onesixth: '\u2159',
    XK.XK_fivesixths: '\u215A',
    XK.XK_careof: '\u2105',
    XK.XK_figdash: '\u2012',
    XK.XK_leftanglebracket: '\u27E8',
    XK.XK_decimalpoint: '\u002E',
    XK.XK_rightanglebracket: '\u27E9',
    XK.XK_oneeighth: '\u215B',
    XK.XK_threeeighths: '\u215C',
    XK.XK_fiveeighths: '\u215D',
    XK.XK_seveneighths: '\u215E',
    XK.XK_trademark: '\u2122',
    XK.XK_signaturemark: '\u2613',
    XK.XK_leftopentriangle: '\u25C1',
    XK.XK_rightopentriangle: '\u25B7',
    XK.XK_emopencircle: '\u25CB',
    XK.XK_emopenrectangle: '\u25AF',
    XK.XK_leftsinglequotemark: '\u2018',
    XK.XK_rightsinglequotemark: '\u2019',
    XK.XK_leftdoublequotemark: '\u201C',
    XK.XK_rightdoublequotemark: '\u201D',
    XK.XK_prescription: '\u211E',
    XK.XK_permille: '\u2030',
    XK.XK_minutes: '\u2032',
    XK.XK_seconds: '\u2033',
    XK.XK_latincross: '\u271D',
    XK.XK_filledrectbullet: '\u25AC',
    XK.XK_filledlefttribullet: '\u25C0',
    XK.XK_filledrighttribullet: '\u25B6',
    XK.XK_emfilledcircle: '\u25CF',
    XK.XK_emfilledrect: '\u25AE',
    XK.XK_enopencircbullet: '\u25E6',
    XK.XK_enopensquarebullet: '\u25AB',
    XK.XK_openrectbullet: '\u25AD',
    XK.XK_opentribulletup: '\u25B3',
    XK.XK_opentribulletdown: '\u25BD',
    XK.XK_openstar: '\u2606',
    XK.XK_enfilledcircbullet: '\u2022',
    XK.XK_enfilledsqbullet: '\u25AA',
    XK.XK_filledtribulletup: '\u25B2',
    XK.XK_filledtribulletdown: '\u25BC',
    XK.XK_leftpointer: '\u261C',
    XK.XK_rightpointer: '\u261E',
    XK.XK_club: '\u2663',
    XK.XK_diamond: '\u2666',
    XK.XK_heart: '\u2665',
    XK.XK_maltesecross: '\u2720',
    XK.XK_dagger: '\u2020',
    XK.XK_doubledagger: '\u2021',
    XK.XK_checkmark: '\u2713',
    XK.XK_ballotcross: '\u2717',
    XK.XK_musicalsharp: '\u266F',
    XK.XK_musicalflat: '\u266D',
    XK.XK_malesymbol: '\u2642',
    XK.XK_femalesymbol: '\u2640',
    XK.XK_telephone: '\u260E',
    XK.XK_telephonerecorder: '\u2315',
    XK.XK_phonographcopyright: '\u2117',
    XK.XK_caret: '\u2038',
    XK.XK_singlelowquotemark: '\u201A',
    XK.XK_doublelowquotemark: '\u201E',
    XK.XK_hebrew_doublelowline: '\u2017',
    XK.XK_hebrew_aleph: '\u05D0',
    XK.XK_hebrew_bet: '\u05D1',
    XK.XK_hebrew_gimel: '\u05D2',
    XK.XK_hebrew_dalet: '\u05D3',
    XK.XK_hebrew_he: '\u05D4',
    XK.XK_hebrew_waw: '\u05D5',
    XK.XK_hebrew_zain: '\u05D6',
    XK.XK_hebrew_chet: '\u05D7',
    XK.XK_hebrew_tet: '\u05D8',
    XK.XK_hebrew_yod: '\u05D9',
    XK.XK_hebrew_finalkaph: '\u05DA',
    XK.XK_hebrew_kaph: '\u05DB',
    XK.XK_hebrew_lamed: '\u05DC',
    XK.XK_hebrew_finalmem: '\u05DD',
    XK.XK_hebrew_mem: '\u05DE',
    XK.XK_hebrew_finalnun: '\u05DF',
    XK.XK_hebrew_nun: '\u05E0',
    XK.XK_hebrew_samech: '\u05E1',
    XK.XK_hebrew_ayin: '\u05E2',
    XK.XK_hebrew_finalpe: '\u05E3',
    XK.XK_hebrew_pe: '\u05E4',
    XK.XK_hebrew_finalzade: '\u05E5',
    XK.XK_hebrew_zade: '\u05E6',
    XK.XK_hebrew_qoph: '\u05E7',
    XK.XK_hebrew_resh: '\u05E8',
    XK.XK_hebrew_shin: '\u05E9',
    XK.XK_hebrew_taw: '\u05EA',
    XK.XK_Thai_kokai: '\u0E01',
    XK.XK_Thai_khokhai: '\u0E02',
    XK.XK_Thai_khokhuat: '\u0E03',
    XK.XK_Thai_khokhwai: '\u0E04',
    XK.XK_Thai_khokhon: '\u0E05',
    XK.XK_Thai_khorakhang: '\u0E06',
    XK.XK_Thai_ngongu: '\u0E07',
    XK.XK_Thai_chochan: '\u0E08',
    XK.XK_Thai_choching: '\u0E09',
    XK.XK_Thai_chochang: '\u0E0A',
    XK.XK_Thai_soso: '\u0E0B',
    XK.XK_Thai_chochoe: '\u0E0C',
    XK.XK_Thai_yoying: '\u0E0D',
    XK.XK_Thai_dochada: '\u0E0E',
    XK.XK_Thai_topatak: '\u0E0F',
    XK.XK_Thai_thothan: '\u0E10',
    XK.XK_Thai_thonangmontho: '\u0E11',
    XK.XK_Thai_thophuthao: '\u0E12',
    XK.XK_Thai_nonen: '\u0E13',
    XK.XK_Thai_dodek: '\u0E14',
    XK.XK_Thai_totao: '\u0E15',
    XK.XK_Thai_thothung: '\u0E16',
    XK.XK_Thai_thothahan: '\u0E17',
    XK.XK_Thai_thothong: '\u0E18',
    XK.XK_Thai_nonu: '\u0E19',
    XK.XK_Thai_bobaimai: '\u0E1A',
    XK.XK_Thai_popla: '\u0E1B',
    XK.XK_Thai_phophung: '\u0E1C',
    XK.XK_Thai_fofa: '\u0E1D',
    XK.XK_Thai_phophan: '\u0E1E',
    XK.XK_Thai_fofan: '\u0E1F',
    XK.XK_Thai_phosamphao: '\u0E20',
    XK.XK_Thai_moma: '\u0E21',
    XK.XK_Thai_yoyak: '\u0E22',
    XK.XK_Thai_rorua: '\u0E23',
    XK.XK_Thai_ru: '\u0E24',
    XK.XK_Thai_loling: '\u0E25',
    XK.XK_Thai_lu: '\u0E26',
    XK.XK_Thai_wowaen: '\u0E27',
    XK.XK_Thai_sosala: '\u0E28',
    XK.XK_Thai_sorusi: '\u0E29',
    XK.XK_Thai_sosua: '\u0E2A',
    XK.XK_Thai_hohip: '\u0E2B',
    XK.XK_Thai_lochula: '\u0E2C',
    XK.XK_Thai_oang: '\u0E2D',
    XK.XK_Thai_honokhuk: '\u0E2E',
    XK.XK_Thai_paiyannoi: '\u0E2F',
    XK.XK_Thai_saraa: '\u0E30',
    XK.XK_Thai_maihanakat: '\u0E31',
    XK.XK_Thai_saraaa: '\u0E32',
    XK.XK_Thai_saraam: '\u0E33',
    XK.XK_Thai_sarai: '\u0E34',
    XK.XK_Thai_saraii: '\u0E35',
    XK.XK_Thai_saraue: '\u0E36',
    XK.XK_Thai_sarauee: '\u0E37',
    XK.XK_Thai_sarau: '\u0E38',
    XK.XK_Thai_sarauu: '\u0E39',
    XK.XK_Thai_phinthu: '\u0E3A',
    XK.XK_Thai_baht: '\u0E3F',
    XK.XK_Thai_sarae: '\u0E40',
    XK.XK_Thai_saraae: '\u0E41',
    XK.XK_Thai_sarao: '\u0E42',
    XK.XK_Thai_saraaimaimuan: '\u0E43',
    XK.XK_Thai_saraaimaimalai: '\u0E44',
    XK.XK_Thai_lakkhangyao: '\u0E45',
    XK.XK_Thai_maiyamok: '\u0E46',
    XK.XK_Thai_maitaikhu: '\u0E47',
    XK.XK_Thai_maiek: '\u0E48',
    XK.XK_Thai_maitho: '\u0E49',
    XK.XK_Thai_maitri: '\u0E4A',
    XK.XK_Thai_maichattawa: '\u0E4B',
    XK.XK_Thai_thanthakhat: '\u0E4C',
    XK.XK_Thai_nikhahit: '\u0E4D',
    XK.XK_Thai_leksun: '\u0E50',
    XK.XK_Thai_leknung: '\u0E51',
    XK.XK_Thai_leksong: '\u0E52',
    XK.XK_Thai_leksam: '\u0E53',
    XK.XK_Thai_leksi: '\u0E54',
    XK.XK_Thai_lekha: '\u0E55',
    XK.XK_Thai_lekhok: '\u0E56',
    XK.XK_Thai_lekchet: '\u0E57',
    XK.XK_Thai_lekpaet: '\u0E58',
    XK.XK_Thai_lekkao: '\u0E59',
    XK.XK_Korean_Won: '\u20A9',
    XK.XK_Armenian_ligature_ew: '\u0587',
    XK.XK_Armenian_full_stop: '\u0589',
    XK.XK_Armenian_verjaket: '\u0589',
    XK.XK_Armenian_separation_mark: '\u055D',
    XK.XK_Armenian_but: '\u055D',
    XK.XK_Armenian_hyphen: '\u058A',
    XK.XK_Armenian_yentamna: '\u058A',
    XK.XK_Armenian_exclam: '\u055C',
    XK.XK_Armenian_amanak: '\u055C',
    XK.XK_Armenian_accent: '\u055B',
    XK.XK_Armenian_shesht: '\u055B',
    XK.XK_Armenian_question: '\u055E',
    XK.XK_Armenian_paruyk: '\u055E',
    XK.XK_Armenian_AYB: '\u0531',
    XK.XK_Armenian_ayb: '\u0561',
    XK.XK_Armenian_BEN: '\u0532',
    XK.XK_Armenian_ben: '\u0562',
    XK.XK_Armenian_GIM: '\u0533',
    XK.XK_Armenian_gim: '\u0563',
    XK.XK_Armenian_DA: '\u0534',
    XK.XK_Armenian_da: '\u0564',
    XK.XK_Armenian_YECH: '\u0535',
    XK.XK_Armenian_yech: '\u0565',
    XK.XK_Armenian_ZA: '\u0536',
    XK.XK_Armenian_za: '\u0566',
    XK.XK_Armenian_E: '\u0537',
    XK.XK_Armenian_e: '\u0567',
    XK.XK_Armenian_AT: '\u0538',
    XK.XK_Armenian_at: '\u0568',
    XK.XK_Armenian_TO: '\u0539',
    XK.XK_Armenian_to: '\u0569',
    XK.XK_Armenian_ZHE: '\u053A',
    XK.XK_Armenian_zhe: '\u056A',
    XK.XK_Armenian_INI: '\u053B',
    XK.XK_Armenian_ini: '\u056B',
    XK.XK_Armenian_LYUN: '\u053C',
    XK.XK_Armenian_lyun: '\u056C',
    XK.XK_Armenian_KHE: '\u053D',
    XK.XK_Armenian_khe: '\u056D',
    XK.XK_Armenian_TSA: '\u053E',
    XK.XK_Armenian_tsa: '\u056E',
    XK.XK_Armenian_KEN: '\u053F',
    XK.XK_Armenian_ken: '\u056F',
    XK.XK_Armenian_HO: '\u0540',
    XK.XK_Armenian_ho: '\u0570',
    XK.XK_Armenian_DZA: '\u0541',
    XK.XK_Armenian_dza: '\u0571',
    XK.XK_Armenian_GHAT: '\u0542',
    XK.XK_Armenian_ghat: '\u0572',
    XK.XK_Armenian_TCHE: '\u0543',
    XK.XK_Armenian_tche: '\u0573',
    XK.XK_Armenian_MEN: '\u0544',
    XK.XK_Armenian_men: '\u0574',
    XK.XK_Armenian_HI: '\u0545',
    XK.XK_Armenian_hi: '\u0575',
    XK.XK_Armenian_NU: '\u0546',
    XK.XK_Armenian_nu: '\u0576',
    XK.XK_Armenian_SHA: '\u0547',
    XK.XK_Armenian_sha: '\u0577',
    XK.XK_Armenian_VO: '\u0548',
    XK.XK_Armenian_vo: '\u0578',
    XK.XK_Armenian_CHA: '\u0549',
    XK.XK_Armenian_cha: '\u0579',
    XK.XK_Armenian_PE: '\u054A',
    XK.XK_Armenian_pe: '\u057A',
    XK.XK_Armenian_JE: '\u054B',
    XK.XK_Armenian_je: '\u057B',
    XK.XK_Armenian_RA: '\u054C',
    XK.XK_Armenian_ra: '\u057C',
    XK.XK_Armenian_SE: '\u054D',
    XK.XK_Armenian_se: '\u057D',
    XK.XK_Armenian_VEV: '\u054E',
    XK.XK_Armenian_vev: '\u057E',
    XK.XK_Armenian_TYUN: '\u054F',
    XK.XK_Armenian_tyun: '\u057F',
    XK.XK_Armenian_RE: '\u0550',
    XK.XK_Armenian_re: '\u0580',
    XK.XK_Armenian_TSO: '\u0551',
    XK.XK_Armenian_tso: '\u0581',
    XK.XK_Armenian_VYUN: '\u0552',
    XK.XK_Armenian_vyun: '\u0582',
    XK.XK_Armenian_PYUR: '\u0553',
    XK.XK_Armenian_pyur: '\u0583',
    XK.XK_Armenian_KE: '\u0554',
    XK.XK_Armenian_ke: '\u0584',
    XK.XK_Armenian_O: '\u0555',
    XK.XK_Armenian_o: '\u0585',
    XK.XK_Armenian_FE: '\u0556',
    XK.XK_Armenian_fe: '\u0586',
    XK.XK_Armenian_apostrophe: '\u055A',
    XK.XK_Georgian_an: '\u10D0',
    XK.XK_Georgian_ban: '\u10D1',
    XK.XK_Georgian_gan: '\u10D2',
    XK.XK_Georgian_don: '\u10D3',
    XK.XK_Georgian_en: '\u10D4',
    XK.XK_Georgian_vin: '\u10D5',
    XK.XK_Georgian_zen: '\u10D6',
    XK.XK_Georgian_tan: '\u10D7',
    XK.XK_Georgian_in: '\u10D8',
    XK.XK_Georgian_kan: '\u10D9',
    XK.XK_Georgian_las: '\u10DA',
    XK.XK_Georgian_man: '\u10DB',
    XK.XK_Georgian_nar: '\u10DC',
    XK.XK_Georgian_on: '\u10DD',
    XK.XK_Georgian_par: '\u10DE',
    XK.XK_Georgian_zhar: '\u10DF',
    XK.XK_Georgian_rae: '\u10E0',
    XK.XK_Georgian_san: '\u10E1',
    XK.XK_Georgian_tar: '\u10E2',
    XK.XK_Georgian_un: '\u10E3',
    XK.XK_Georgian_phar: '\u10E4',
    XK.XK_Georgian_khar: '\u10E5',
    XK.XK_Georgian_ghan: '\u10E6',
    XK.XK_Georgian_qar: '\u10E7',
    XK.XK_Georgian_shin: '\u10E8',
    XK.XK_Georgian_chin: '\u10E9',
    XK.XK_Georgian_can: '\u10EA',
    XK.XK_Georgian_jil: '\u10EB',
    XK.XK_Georgian_cil: '\u10EC',
    XK.XK_Georgian_char: '\u10ED',
    XK.XK_Georgian_xan: '\u10EE',
    XK.XK_Georgian_jhan: '\u10EF',
    XK.XK_Georgian_hae: '\u10F0',
    XK.XK_Georgian_he: '\u10F1',
    XK.XK_Georgian_hie: '\u10F2',
    XK.XK_Georgian_we: '\u10F3',
    XK.XK_Georgian_har: '\u10F4',
    XK.XK_Georgian_hoe: '\u10F5',
    XK.XK_Georgian_fi: '\u10F6',
    XK.XK_Xabovedot: '\u1E8A',
    XK.XK_Ibreve: '\u012C',
    XK.XK_Zstroke: '\u01B5',
    XK.XK_Gcaron: '\u01E6',
    XK.XK_Ocaron: '\u01D2',
    XK.XK_Obarred: '\u019F',
    XK.XK_xabovedot: '\u1E8B',
    XK.XK_ibreve: '\u012D',
    XK.XK_zstroke: '\u01B6',
    XK.XK_gcaron: '\u01E7',
    XK.XK_ocaron: '\u01D2',
    XK.XK_obarred: '\u0275',
    XK.XK_SCHWA: '\u018F',
    XK.XK_schwa: '\u0259',
    XK.XK_EZH: '\u01B7',
    XK.XK_ezh: '\u0292',
    XK.XK_Lbelowdot: '\u1E36',
    XK.XK_lbelowdot: '\u1E37',
    XK.XK_Abelowdot: '\u1EA0',
    XK.XK_abelowdot: '\u1EA1',
    XK.XK_Ahook: '\u1EA2',
    XK.XK_ahook: '\u1EA3',
    XK.XK_Acircumflexacute: '\u1EA4',
    XK.XK_acircumflexacute: '\u1EA5',
    XK.XK_Acircumflexgrave: '\u1EA6',
    XK.XK_acircumflexgrave: '\u1EA7',
    XK.XK_Acircumflexhook: '\u1EA8',
    XK.XK_acircumflexhook: '\u1EA9',
    XK.XK_Acircumflextilde: '\u1EAA',
    XK.XK_acircumflextilde: '\u1EAB',
    XK.XK_Acircumflexbelowdot: '\u1EAC',
    XK.XK_acircumflexbelowdot: '\u1EAD',
    XK.XK_Abreveacute: '\u1EAE',
    XK.XK_abreveacute: '\u1EAF',
    XK.XK_Abrevegrave: '\u1EB0',
    XK.XK_abrevegrave: '\u1EB1',
    XK.XK_Abrevehook: '\u1EB2',
    XK.XK_abrevehook: '\u1EB3',
    XK.XK_Abrevetilde: '\u1EB4',
    XK.XK_abrevetilde: '\u1EB5',
    XK.XK_Abrevebelowdot: '\u1EB6',
    XK.XK_abrevebelowdot: '\u1EB7',
    XK.XK_Ebelowdot: '\u1EB8',
    XK.XK_ebelowdot: '\u1EB9',
    XK.XK_Ehook: '\u1EBA',
    XK.XK_ehook: '\u1EBB',
    XK.XK_Etilde: '\u1EBC',
    XK.XK_etilde: '\u1EBD',
    XK.XK_Ecircumflexacute: '\u1EBE',
    XK.XK_ecircumflexacute: '\u1EBF',
    XK.XK_Ecircumflexgrave: '\u1EC0',
    XK.XK_ecircumflexgrave: '\u1EC1',
    XK.XK_Ecircumflexhook: '\u1EC2',
    XK.XK_ecircumflexhook: '\u1EC3',
    XK.XK_Ecircumflextilde: '\u1EC4',
    XK.XK_ecircumflextilde: '\u1EC5',
    XK.XK_Ecircumflexbelowdot: '\u1EC6',
    XK.XK_ecircumflexbelowdot: '\u1EC7',
    XK.XK_Ihook: '\u1EC8',
    XK.XK_ihook: '\u1EC9',
    XK.XK_Ibelowdot: '\u1ECA',
    XK.XK_ibelowdot: '\u1ECB',
    XK.XK_Obelowdot: '\u1ECC',
    XK.XK_obelowdot: '\u1ECD',
    XK.XK_Ohook: '\u1ECE',
    XK.XK_ohook: '\u1ECF',
    XK.XK_Ocircumflexacute: '\u1ED0',
    XK.XK_ocircumflexacute: '\u1ED1',
    XK.XK_Ocircumflexgrave: '\u1ED2',
    XK.XK_ocircumflexgrave: '\u1ED3',
    XK.XK_Ocircumflexhook: '\u1ED4',
    XK.XK_ocircumflexhook: '\u1ED5',
    XK.XK_Ocircumflextilde: '\u1ED6',
    XK.XK_ocircumflextilde: '\u1ED7',
    XK.XK_Ocircumflexbelowdot: '\u1ED8',
    XK.XK_ocircumflexbelowdot: '\u1ED9',
    XK.XK_Ohornacute: '\u1EDA',
    XK.XK_ohornacute: '\u1EDB',
    XK.XK_Ohorngrave: '\u1EDC',
    XK.XK_ohorngrave: '\u1EDD',
    XK.XK_Ohornhook: '\u1EDE',
    XK.XK_ohornhook: '\u1EDF',
    XK.XK_Ohorntilde: '\u1EE0',
    XK.XK_ohorntilde: '\u1EE1',
    XK.XK_Ohornbelowdot: '\u1EE2',
    XK.XK_ohornbelowdot: '\u1EE3',
    XK.XK_Ubelowdot: '\u1EE4',
    XK.XK_ubelowdot: '\u1EE5',
    XK.XK_Uhook: '\u1EE6',
    XK.XK_uhook: '\u1EE7',
    XK.XK_Uhornacute: '\u1EE8',
    XK.XK_uhornacute: '\u1EE9',
    XK.XK_Uhorngrave: '\u1EEA',
    XK.XK_uhorngrave: '\u1EEB',
    XK.XK_Uhornhook: '\u1EEC',
    XK.XK_uhornhook: '\u1EED',
    XK.XK_Uhorntilde: '\u1EEE',
    XK.XK_uhorntilde: '\u1EEF',
    XK.XK_Uhornbelowdot: '\u1EF0',
    XK.XK_uhornbelowdot: '\u1EF1',
    XK.XK_Ybelowdot: '\u1EF4',
    XK.XK_ybelowdot: '\u1EF5',
    XK.XK_Yhook: '\u1EF6',
    XK.XK_yhook: '\u1EF7',
    XK.XK_Ytilde: '\u1EF8',
    XK.XK_ytilde: '\u1EF9',
    XK.XK_Ohorn: '\u01A0',
    XK.XK_ohorn: '\u01A1',
    XK.XK_Uhorn: '\u01AF',
    XK.XK_uhorn: '\u01B0',
    XK.XK_EcuSign: '\u20A0',
    XK.XK_ColonSign: '\u20A1',
    XK.XK_CruzeiroSign: '\u20A2',
    XK.XK_FFrancSign: '\u20A3',
    XK.XK_LiraSign: '\u20A4',
    XK.XK_MillSign: '\u20A5',
    XK.XK_NairaSign: '\u20A6',
    XK.XK_PesetaSign: '\u20A7',
    XK.XK_RupeeSign: '\u20A8',
    XK.XK_WonSign: '\u20A9',
    XK.XK_NewSheqelSign: '\u20AA',
    XK.XK_DongSign: '\u20AB',
    XK.XK_EuroSign: '\u20AC',
    XK.XK_zerosuperior: '\u2070',
    XK.XK_foursuperior: '\u2074',
    XK.XK_fivesuperior: '\u2075',
    XK.XK_sixsuperior: '\u2076',
    XK.XK_sevensuperior: '\u2077',
    XK.XK_eightsuperior: '\u2078',
    XK.XK_ninesuperior: '\u2079',
    XK.XK_zerosubscript: '\u2080',
    XK.XK_onesubscript: '\u2081',
    XK.XK_twosubscript: '\u2082',
    XK.XK_threesubscript: '\u2083',
    XK.XK_foursubscript: '\u2084',
    XK.XK_fivesubscript: '\u2085',
    XK.XK_sixsubscript: '\u2086',
    XK.XK_sevensubscript: '\u2087',
    XK.XK_eightsubscript: '\u2088',
    XK.XK_ninesubscript: '\u2089',
    XK.XK_partdifferential: '\u2202',
    XK.XK_emptyset: '\u2205',
    XK.XK_elementof: '\u2208',
    XK.XK_notelementof: '\u2209',
    XK.XK_containsas: '\u220B',
    XK.XK_squareroot: '\u221A',
    XK.XK_cuberoot: '\u221B',
    XK.XK_fourthroot: '\u221C',
    XK.XK_dintegral: '\u222C',
    XK.XK_tintegral: '\u222D',
    XK.XK_because: '\u2235',
    XK.XK_approxeq: '\u2245',
    XK.XK_notapproxeq: '\u2247',
    XK.XK_notidentical: '\u2262',
    XK.XK_stricteq: '\u2263',
    XK.XK_Sinh_ng: '\u0D82',
    XK.XK_Sinh_h2: '\u0D83',
    XK.XK_Sinh_a: '\u0D85',
    XK.XK_Sinh_aa: '\u0D86',
    XK.XK_Sinh_ae: '\u0D87',
    XK.XK_Sinh_aee: '\u0D88',
    XK.XK_Sinh_i: '\u0D89',
    XK.XK_Sinh_ii: '\u0D8A',
    XK.XK_Sinh_u: '\u0D8B',
    XK.XK_Sinh_uu: '\u0D8C',
    XK.XK_Sinh_ri: '\u0D8D',
    XK.XK_Sinh_rii: '\u0D8E',
    XK.XK_Sinh_lu: '\u0D8F',
    XK.XK_Sinh_luu: '\u0D90',
    XK.XK_Sinh_e: '\u0D91',
    XK.XK_Sinh_ee: '\u0D92',
    XK.XK_Sinh_ai: '\u0D93',
    XK.XK_Sinh_o: '\u0D94',
    XK.XK_Sinh_oo: '\u0D95',
    XK.XK_Sinh_au: '\u0D96',
    XK.XK_Sinh_ka: '\u0D9A',
    XK.XK_Sinh_kha: '\u0D9B',
    XK.XK_Sinh_ga: '\u0D9C',
    XK.XK_Sinh_gha: '\u0D9D',
    XK.XK_Sinh_ng2: '\u0D9E',
    XK.XK_Sinh_nga: '\u0D9F',
    XK.XK_Sinh_ca: '\u0DA0',
    XK.XK_Sinh_cha: '\u0DA1',
    XK.XK_Sinh_ja: '\u0DA2',
    XK.XK_Sinh_jha: '\u0DA3',
    XK.XK_Sinh_nya: '\u0DA4',
    XK.XK_Sinh_jnya: '\u0DA5',
    XK.XK_Sinh_nja: '\u0DA6',
    XK.XK_Sinh_tta: '\u0DA7',
    XK.XK_Sinh_ttha: '\u0DA8',
    XK.XK_Sinh_dda: '\u0DA9',
    XK.XK_Sinh_ddha: '\u0DAA',
    XK.XK_Sinh_nna: '\u0DAB',
    XK.XK_Sinh_ndda: '\u0DAC',
    XK.XK_Sinh_tha: '\u0DAD',
    XK.XK_Sinh_thha: '\u0DAE',
    XK.XK_Sinh_dha: '\u0DAF',
    XK.XK_Sinh_dhha: '\u0DB0',
    XK.XK_Sinh_na: '\u0DB1',
    XK.XK_Sinh_ndha: '\u0DB3',
    XK.XK_Sinh_pa: '\u0DB4',
    XK.XK_Sinh_pha: '\u0DB5',
    XK.XK_Sinh_ba: '\u0DB6',
    XK.XK_Sinh_bha: '\u0DB7',
    XK.XK_Sinh_ma: '\u0DB8',
    XK.XK_Sinh_mba: '\u0DB9',
    XK.XK_Sinh_ya: '\u0DBA',
    XK.XK_Sinh_ra: '\u0DBB',
    XK.XK_Sinh_la: '\u0DBD',
    XK.XK_Sinh_va: '\u0DC0',
    XK.XK_Sinh_sha: '\u0DC1',
    XK.XK_Sinh_ssha: '\u0DC2',
    XK.XK_Sinh_sa: '\u0DC3',
    XK.XK_Sinh_ha: '\u0DC4',
    XK.XK_Sinh_lla: '\u0DC5',
    XK.XK_Sinh_fa: '\u0DC6',
    XK.XK_Sinh_al: '\u0DCA',
    XK.XK_Sinh_aa2: '\u0DCF',
    XK.XK_Sinh_ae2: '\u0DD0',
    XK.XK_Sinh_aee2: '\u0DD1',
    XK.XK_Sinh_i2: '\u0DD2',
    XK.XK_Sinh_ii2: '\u0DD3',
    XK.XK_Sinh_u2: '\u0DD4',
    XK.XK_Sinh_uu2: '\u0DD6',
    XK.XK_Sinh_ru2: '\u0DD8',
    XK.XK_Sinh_e2: '\u0DD9',
    XK.XK_Sinh_ee2: '\u0DDA',
    XK.XK_Sinh_ai2: '\u0DDB',
    XK.XK_Sinh_o2: '\u0DDC',
    XK.XK_Sinh_oo2: '\u0DDD',
    XK.XK_Sinh_au2: '\u0DDE',
    XK.XK_Sinh_lu2: '\u0DDF',
    XK.XK_Sinh_ruu2: '\u0DF2',
    XK.XK_Sinh_luu2: '\u0DF3',
    XK.XK_Sinh_kunddaliya: '\u0DF4',
    'XK_KP_Space': ' ',
    XK.XK_KP_0: '0',
    XK.XK_KP_1: '1',
    XK.XK_KP_2: '2',
    XK.XK_KP_3: '3',
    XK.XK_KP_4: '4',
    XK.XK_KP_5: '5',
    XK.XK_KP_6: '6',
    XK.XK_KP_7: '7',
    XK.XK_KP_8: '8',
    XK.XK_KP_9: '9',
    XK.XK_KP_Divide: '/',
    XK.XK_KP_Multiply: '*',
    XK.XK_KP_Add: '+',
    XK.XK_KP_Subtract: '-',
    XK.XK_KP_Decimal: '.',
    XK.XK_KP_Separator: ','}

MODIFIERS = {
    XK.XK_Shift_L,
    XK.XK_Shift_R,
    XK.XK_Caps_Lock,
    XK.XK_Num_Lock,
    XK.XK_Shift_Lock,
    XK.XK_ISO_Level3_Shift,
    XK.XK_Alt_L,
    XK.XK_Alt_R,
    XK.XK_Control_L,
    XK.XK_Control_R,
    XK.XK_Meta_L,
    XK.XK_Meta_R,
    XK.XK_Super_L,
    XK.XK_Super_R,
    XK.XK_Hyper_L,
    XK.XK_Hyper_R}

NO_INDEX = {
    XK.XK_Shift_L,
    XK.XK_Shift_R,
    XK.XK_Caps_Lock,
    XK.XK_Num_Lock,
    XK.XK_Shift_Lock,
    XK.XK_ISO_Level3_Shift,
    XK.XK_Scroll_Lock,
    XK.XK_Alt_L,
    XK.XK_Alt_R,
    XK.XK_Control_L,
    XK.XK_Control_R,
    XK.XK_Meta_L,
    XK.XK_Meta_R,
    XK.XK_Super_L,
    XK.XK_Super_R,
    XK.XK_Hyper_L,
    XK.XK_Hyper_R,
    XK.XK_Menu,
    XK.XK_Return,
    XK.XK_Escape,
    XK.XK_Insert,
    XK.XK_Delete,
    XK.XK_Home,
    XK.XK_Page_Up,
    XK.XK_Page_Down,
    XK.XK_End,
    XK.XK_F1,
    XK.XK_F2,
    XK.XK_F3,
    XK.XK_F4,
    XK.XK_F5,
    XK.XK_F6,
    XK.XK_F7,
    XK.XK_F8,
    XK.XK_F9,
    XK.XK_F10,
    XK.XK_F11,
    XK.XK_F12,
    XK.XK_Up,
    XK.XK_Down,
    XK.XK_Left,
    XK.XK_Right}
